@@ -1,29 +1,31 @@
 /*
-	Copyright (C) 2003  Sridhar Ratna <srid@nearfar.org>
+  Copyright (C) 2003  Sridhar Ratnakumar <srid@nearfar.org>
 	
-	This file is part of GNUSim8085.
+  This file is part of GNUSim8085.
 
-	GNUSim8085 is free software; you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation; either version 2 of the License, or
-	(at your option) any later version.
+  GNUSim8085 is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-	GNUSim8085 is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
+  GNUSim8085 is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-	You should have received a copy of the GNU General Public License
-	along with GNUSim8085; if not, write to the Free Software
-	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with GNUSim8085; if not, write to the Free Software
+  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <stdio.h>
+#include <stdlib.h>
 #include <gtk/gtk.h>
 
 
 gboolean
 on_window_main_delete_event (GtkWidget * widget,
-			     GdkEvent * event, gpointer user_data);
+							 GdkEvent * event, gpointer user_data);
 
 void on_new1_activate (GtkMenuItem * menuitem, gpointer user_data);
 
@@ -62,7 +64,7 @@ on_toggle_breakpoint1_activate (GtkMenuItem * menuitem, gpointer user_data);
 
 void
 on_clear_all_breakpoints1_activate (GtkMenuItem * menuitem,
-				    gpointer user_data);
+									gpointer user_data);
 
 void on_stop_execution1_activate (GtkMenuItem * menuitem, gpointer user_data);
 
